pub struct ShaderFill { /* private fields */ }Implementations
Sourceimpl ShaderFill
impl ShaderFill
pub fn new<F>( sksl: impl Into<Arc<str>>, effect: RuntimeEffect, provider: F, ) -> Self
pub fn from_provider<S>(
sksl: impl Into<Arc<str>>,
effect: RuntimeEffect,
provider: S,
) -> Selfwhere
S: ShaderProvider + 'static,
Sourcepub fn prepare_shader(&self, bounds: Area) -> Option<Shader>
pub fn prepare_shader(&self, bounds: Area) -> Option<Shader>
Prepare the shader for use by providing the necessary uniforms. Returns None if the provider could not produce a [Shader], in which case the renderer will fallback to no fill.